@@ -11,7 +11,9 @@ from aeppl.printing import latex_pprint, pprint
 
 # isort: off
 # Add optimizations to the DBs
+import aeppl.cumsum
 import aeppl.mixture
 import aeppl.scan
+import aeppl.truncation
 
 # isort: on
